@@ -554,34 +554,37 @@ int main(int argc, char** argv)
             // ====== Old version 1 table ===================================
             if(tableVersion == 1) {
                std::string ts;
+               std::string rtt;
                if( (backend & DatabaseBackendType::SQL_PostgreSQL) == DatabaseBackendType::SQL_PostgreSQL ) {
-                  ts = "CAST((1000000000.0 * EXTRACT(EPOCH FROM TimeStamp)) AS BIGINT)";
+                  ts  = "CAST((1000000000.0 * EXTRACT(EPOCH FROM TimeStamp)) AS BIGINT)";
+                  rtt = "1000 * CAST(RTT AS BIGINT)";
                }
                else {
-                  ts = "UNIX_TIMESTAMP(CONVERT_TZ(TimeStamp, '+00:00', @@global.time_zone)) * 1000000000";
+                  ts  = "UNIX_TIMESTAMP(CONVERT_TZ(TimeStamp, '+00:00', @@global.time_zone)) * 1000000000";
+                  rtt = "1000 * RTT";
                }
                statement
                   << "SELECT"
-                     " " << ts << " AS SendTimestamp,"
-                     " 0            AS MeasurementID,"
-                     " FromIP       AS SourceIP,"
-                     " ToIP         AS DestinationIP,"
-                     " 105          AS Protocol,"         /* 'i', since HiPerConTracer 1.x only supports ICMP */
-                     " TC           AS TrafficClass,"
-                     " 0            AS BurstSeq,"
-                     " PktSize      AS PacketSize,"
-                     " 0            AS ResponseSize,"
-                     " Checksum     AS Checksum,"
-                     " 0            AS SourcePort,"
-                     " 0            AS DestinationPort,"
-                     " Status       AS Status,"
-                     " 0            AS TimeSource,"
-                     " -1           AS Delay_AppSend,"
-                     " -1           AS Delay_Queuing,"
-                     " -1           AS Delay_AppReceive,"
-                     " 1000 * RTT   AS RTT_App,"
-                     " -1           AS RTT_SW,"
-                     " -1           AS RTT_HW "
+                     " " << ts <<  " AS SendTimestamp,"
+                     " 0             AS MeasurementID,"
+                     " FromIP        AS SourceIP,"
+                     " ToIP          AS DestinationIP,"
+                     " 105           AS Protocol,"         /* 'i', since HiPerConTracer 1.x only supports ICMP */
+                     " TC            AS TrafficClass,"
+                     " 0             AS BurstSeq,"
+                     " PktSize       AS PacketSize,"
+                     " 0             AS ResponseSize,"
+                     " Checksum      AS Checksum,"
+                     " 0             AS SourcePort,"
+                     " 0             AS DestinationPort,"
+                     " Status        AS Status,"
+                     " 0             AS TimeSource,"
+                     " -1            AS Delay_AppSend,"
+                     " -1            AS Delay_Queuing,"
+                     " -1            AS Delay_AppReceive,"
+                     " " << rtt << " AS RTT_App,"
+                     " -1            AS RTT_SW,"
+                     " -1            AS RTT_HW "
                      "FROM " << ((tableName.size() == 0) ? "Ping" : tableName);
                addSQLWhere(statement, "TimeStamp", fromTimeStamp, toTimeStamp, fromMeasurementID, toMeasurementID, true);
             }
@@ -719,39 +722,42 @@ int main(int argc, char** argv)
             // ====== Old version 1 table ===================================
             if(tableVersion == 1) {
                std::string ts;
+               std::string rtt;
                if( (backend & DatabaseBackendType::SQL_PostgreSQL) == DatabaseBackendType::SQL_PostgreSQL ) {
-                  ts = "CAST((1000000000.0 * EXTRACT(EPOCH FROM TimeStamp)) AS BIGINT)";
+                  ts  = "CAST((1000000000.0 * EXTRACT(EPOCH FROM TimeStamp)) AS BIGINT)";
+                  rtt = "1000 * CAST(RTT AS BIGINT)";
                }
                else {
-                  ts = "UNIX_TIMESTAMP(CONVERT_TZ(TimeStamp, '+00:00', @@global.time_zone)) * 1000000000";
+                  ts  = "UNIX_TIMESTAMP(CONVERT_TZ(TimeStamp, '+00:00', @@global.time_zone)) * 1000000000";
+                  rtt = "1000 * RTT";
                }
                statement
                   << "SELECT"
-                     " " << ts << " AS Timestamp,"
-                     " 0            AS MeasurementID,"
-                     " FromIP       AS SourceIP,"
-                     " ToIP         AS DestinationIP,"
-                     " 105          AS Protocol,"     /* 'i', since HiPerConTracer 1.x only supports ICMP */
-                     " TC           AS TrafficClass,"
-                     " Round        AS RoundNumber,"
-                     " HopNumber    AS HopNumber,"
-                     " TotalHops    AS TotalHops,"
-                     " PktSize      AS PacketSize,"
-                     " 0            AS ResponseSize,"
-                     " Checksum     AS Checksum,"
-                     " 0            AS SourcePort,"
-                     " 0            AS DestinationPort,"
-                     " Status       AS Status,"
-                     " PathHash     AS PathHash,"
-                     " " << ts << " AS SendTimestamp,"
-                     " HopIP        AS HopIP,"
-                     " 0            AS TimeSource,"
-                     " -1           AS Delay_AppSend,"
-                     " -1           AS Delay_Queuing,"
-                     " -1           AS Delay_AppReceive,"
-                     " 1000 * RTT   AS RTT_App,"
-                     " -1           AS RTT_SW,"
-                     " -1           AS RTT_HW "
+                     " " << ts << "  AS Timestamp,"
+                     " 0             AS MeasurementID,"
+                     " FromIP        AS SourceIP,"
+                     " ToIP          AS DestinationIP,"
+                     " 105           AS Protocol,"     /* 'i', since HiPerConTracer 1.x only supports ICMP */
+                     " TC            AS TrafficClass,"
+                     " Round         AS RoundNumber,"
+                     " HopNumber     AS HopNumber,"
+                     " TotalHops     AS TotalHops,"
+                     " PktSize       AS PacketSize,"
+                     " 0             AS ResponseSize,"
+                     " Checksum      AS Checksum,"
+                     " 0             AS SourcePort,"
+                     " 0             AS DestinationPort,"
+                     " Status        AS Status,"
+                     " PathHash      AS PathHash,"
+                     " " << ts << "  AS SendTimestamp,"
+                     " HopIP         AS HopIP,"
+                     " 0             AS TimeSource,"
+                     " -1            AS Delay_AppSend,"
+                     " -1            AS Delay_Queuing,"
+                     " -1            AS Delay_AppReceive,"
+                     " " << rtt << " AS RTT_App,"
+                     " -1            AS RTT_SW,"
+                     " -1            AS RTT_HW "
                      "FROM " << ((tableName.size() == 0) ? "Traceroute" : tableName);
                addSQLWhere(statement, "TimeStamp", fromTimeStamp, toTimeStamp, fromMeasurementID, toMeasurementID, true);
             }
