@@ -807,8 +807,7 @@ int main(int argc, char** argv)
    try {
       boost::program_options::store(boost::program_options::command_line_parser(argc, argv).
                                        style(
-                                          boost::program_options::command_line_style::style_t::default_style|
-                                          boost::program_options::command_line_style::style_t::allow_long_disguise
+                                          boost::program_options::command_line_style::style_t::unix_style
                                        ).
                                        options(allOptions).positional(positionalParameters).
                                        run(), vm);
@@ -874,14 +873,14 @@ int main(int argc, char** argv)
 
    // ====== Initialize =====================================================
    initialiseLogger(logLevel, logColor,
-                    (logFile != std::filesystem::path()) ? logFile.string().c_str() : nullptr);
+                    (!logFile.empty()) ? logFile.string().c_str() : nullptr);
 
    // ====== Open output file ===============================================
    std::string                         extension(outputFileName.extension());
    std::ofstream                       outputFile;
    boost::iostreams::filtering_ostream outputStream;
    const std::filesystem::path         tmpOutputFileName = outputFileName.string() + ".tmp";
-   if(outputFileName != std::filesystem::path()) {
+   if(!outputFileName.empty()) {
       outputFile.open(tmpOutputFileName, std::ios_base::out | std::ios_base::binary);
       if(!outputFile.is_open()) {
          HPCT_LOG(fatal) << "Failed to create output file " << tmpOutputFileName;
@@ -968,7 +967,7 @@ int main(int argc, char** argv)
                      << std::chrono::duration_cast<std::chrono::milliseconds>(t4 - t3).count() << " ms";
    }
 
-   if(outputFileName != std::filesystem::path()) {
+   if(!outputFileName.empty()) {
       try {
          std::filesystem::rename(tmpOutputFileName, outputFileName);
       }
