@@ -1,18 +1,16 @@
-// =================================================================
-//          #     #                 #     #
-//          ##    #   ####   #####  ##    #  ######   #####
-//          # #   #  #    #  #    # # #   #  #          #
-//          #  #  #  #    #  #    # #  #  #  #####      #
-//          #   # #  #    #  #####  #   # #  #          #
-//          #    ##  #    #  #   #  #    ##  #          #
-//          #     #   ####   #    # #     #  ######     #
+// ==========================================================================
+//     _   _ _ ____            ____          _____
+//    | | | (_)  _ \ ___ _ __ / ___|___  _ _|_   _| __ __ _  ___ ___ _ __
+//    | |_| | | |_) / _ \ '__| |   / _ \| '_ \| || '__/ _` |/ __/ _ \ '__|
+//    |  _  | |  __/  __/ |  | |__| (_) | | | | || | | (_| | (_|  __/ |
+//    |_| |_|_|_|   \___|_|   \____\___/|_| |_|_||_|  \__,_|\___\___|_|
 //
-//       ---   The NorNet Testbed for Multi-Homed Systems  ---
-//                       https://www.nntb.no
-// =================================================================
+//       ---  High-Performance Connectivity Tracer (HiPerConTracer)  ---
+//                 https://www.nntb.no/~dreibh/hipercontracer/
+// ==========================================================================
 //
 // High-Performance Connectivity Tracer (HiPerConTracer)
-// Copyright (C) 2015-2022 by Thomas Dreibholz
+// Copyright (C) 2015-2025 by Thomas Dreibholz
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -35,19 +33,10 @@
 #include <string.h>
 #include <unistd.h>
 
-#include <iostream>
-
+#include <fstream>
 #include <boost/algorithm/string.hpp>
 
 
-// ###### Convert time to microseconds since the epoch ######################
-uint64_t usSinceEpoch(const std::chrono::system_clock::time_point& time)
-{
-   const std::chrono::system_clock::duration duration = time.time_since_epoch();
-   return std::chrono::duration_cast<std::chrono::microseconds>(duration).count();
-}
-
-
 // ###### Reduce permissions of process #####################################
 const passwd* getUser(const char* user)
 {
@@ -67,6 +56,56 @@ const passwd* getUser(const char* user)
 }
 
 
+// ###### Check whether path1 is a subdirectory of path2 ####################
+// Returns: -1, if path1 is not a subdirectory of path2
+//           0, if path1 is identical to path2
+//           N, if path1 is N-th level subdirectory of path2
+int subDirectoryOf(const std::filesystem::path& path1,
+                   const std::filesystem::path& path2)
+{
+   try {
+      const std::filesystem::path ca1 = std::filesystem::canonical(std::filesystem::absolute(path1));
+      const std::filesystem::path ca2 = std::filesystem::canonical(std::filesystem::absolute(path2));
+
+      std::filesystem::path::const_iterator it1 = ca1.begin();
+      std::filesystem::path::const_iterator it2 = ca2.begin();
+      while(it2 != ca2.end()) {
+         if(it1 == ca1.end()) {   // End of path1 -> path1 not a subdirectory of path2
+            return false;
+         }
+         else if(*it1 != *it2) {   // Different directories -> path1 not a subdirectory of path 2
+            return false;
+         }
+         it1++; it2++;
+      }
+      // Full overlap of all parts of path2
+      // -> path1 is a subdirectory of path 2, if path1 is not yet fully iterated
+      unsigned int depth = 0;
+      while(it1 != ca1.end()) {
+         it1++;
+         depth++;
+      }
+      return depth;
+   }
+   catch(...) { }
+   return -1;
+}
+
+
+// ###### Destructor ########################################################
+std::filesystem::path relativeTo(const std::filesystem::path& dataFile,
+                                 const std::filesystem::path& basePath)
+{
+   std::error_code       ec;
+   std::filesystem::path relativePath = std::filesystem::relative(dataFile, basePath, ec);
+   if(ec) {
+      // Failed to get relative path -> return existing path.
+      return dataFile;
+   }
+   return relativePath;
+}
+
+
 // ###### Reduce privileges of process ######################################
 bool reducePrivileges(const passwd* pw)
 {
@@ -134,33 +173,30 @@ bool addSourceAddress(std::map<boost::asio::ip::address, std::set<uint8_t>>& arr
                       const std::string&                                     addressString,
                       bool                                                   tryToResolve)
 {
-   boost::system::error_code errorCode;
    std::vector<std::string>  addressParameters;
 
    boost::split(addressParameters, addressString, boost::is_any_of(","));
    if(addressParameters.size() > 0) {
-      const boost::asio::ip::address address = boost::asio::ip::address::from_string(addressParameters[0], errorCode);
+      boost::system::error_code      errorCode;
+      const boost::asio::ip::address address = boost::asio::ip::make_address(addressParameters[0], errorCode);
       if(errorCode != boost::system::errc::success) {
          if(tryToResolve) {
-            boost::asio::io_service ios;
-            boost::asio::ip::tcp::resolver::query resolver_query(
-               addressString, "0", boost::asio::ip::tcp::resolver::query::numeric_service);
-            boost::asio::ip::tcp::resolver resolver(ios);
-            boost::system::error_code ec;
-            boost::asio::ip::tcp::resolver::iterator iterator =
-               resolver.resolve(resolver_query, ec);
-            if(ec) {
-               std::cerr << "Failed to resolve a DNS name " << addressString << ": " << ec.message() << std::endl;
-               exit(1);
+            boost::asio::io_context        ioContext;
+            boost::asio::ip::tcp::resolver resolver(ioContext);
+            boost::asio::ip::tcp::resolver::results_type endpoints =
+               resolver.resolve(addressString, "0",
+                              boost::asio::ip::tcp::resolver::numeric_service, errorCode);
+            if(errorCode) {
+               HPCT_LOG(error) << "Failed to resolve DNS name " << addressString << ": " << errorCode.message();
+               return false;
             }
-            for(   ; iterator != boost::asio::ip::tcp::resolver::iterator(); iterator++) {
-               const boost::asio::ip::tcp::endpoint& endpoint = *iterator;
+            for(boost::asio::ip::tcp::endpoint endpoint : endpoints) {
                HPCT_LOG(info) << addressString << " -> " << endpoint.address().to_string();
                addSourceAddress(array, endpoint.address().to_string(), false);
             }
             return true;
          }
-         std::cerr << "ERROR: Bad source address " << addressParameters[0] << "!" << std::endl;
+         HPCT_LOG(error) << "Bad source address " << addressParameters[0];
          return false;
       }
       std::map<boost::asio::ip::address, std::set<uint8_t>>::iterator found = array.find(address);
@@ -182,7 +218,7 @@ bool addSourceAddress(std::map<boost::asio::ip::address, std::set<uint8_t>>& arr
             if(trafficClass == ~0U) {
                trafficClass = std::strtoul(addressParameters[i].c_str(), nullptr, 16);
                if(trafficClass > 0xff) {
-                  std::cerr << "ERROR: Bad traffic class " << addressParameters[i] << "!" << std::endl;
+                  HPCT_LOG(error) << "Bad traffic class " << addressParameters[i];
                   return false;
                }
             }
@@ -194,7 +230,7 @@ bool addSourceAddress(std::map<boost::asio::ip::address, std::set<uint8_t>>& arr
       }
    }
    else {
-      std::cerr << "ERROR: Invalid source address specification " << addressString << std::endl;
+      HPCT_LOG(error) << "Invalid source address specification " << addressString;
       return false;
    }
    return true;
@@ -207,30 +243,69 @@ bool addDestinationAddress(std::set<boost::asio::ip::address>& array,
                            bool                                tryToResolve)
 {
    boost::system::error_code errorCode;
-   boost::asio::ip::address  address = boost::asio::ip::address::from_string(addressString, errorCode);
+   boost::asio::ip::address  address = boost::asio::ip::make_address(addressString, errorCode);
    if(errorCode != boost::system::errc::success) {
       if(tryToResolve) {
-         boost::asio::io_service ios;
-         boost::asio::ip::tcp::resolver::query resolver_query(
-            addressString, "0", boost::asio::ip::tcp::resolver::query::numeric_service);
-         boost::asio::ip::tcp::resolver resolver(ios);
-         boost::system::error_code ec;
-         boost::asio::ip::tcp::resolver::iterator iterator =
-            resolver.resolve(resolver_query, ec);
-         if(ec) {
-            std::cerr << "Failed to resolve a DNS name " << addressString << ": " << ec.message() << std::endl;
-            exit(1);
+         boost::asio::io_context        ioContext;
+         boost::asio::ip::tcp::resolver resolver(ioContext);
+         boost::asio::ip::tcp::resolver::results_type endpoints =
+            resolver.resolve(addressString, "0",
+                             boost::asio::ip::tcp::resolver::numeric_service, errorCode);
+         if(errorCode) {
+            HPCT_LOG(error) << "Failed to resolve DNS name " << addressString << ": " << errorCode.message();
+            return false;
          }
-         for(   ; iterator != boost::asio::ip::tcp::resolver::iterator(); iterator++) {
-            const boost::asio::ip::tcp::endpoint endpoint = *iterator;
+         for(boost::asio::ip::tcp::endpoint endpoint : endpoints) {
             HPCT_LOG(info) << addressString << " -> " << endpoint.address().to_string();
             addDestinationAddress(array, endpoint.address().to_string(), false);
          }
          return true;
       }
-      std::cerr << "ERROR: Bad destination address " << addressString << "!" << std::endl;
+      HPCT_LOG(error) << "Bad destination address " << addressString;
       return false;
    }
    array.insert(address);
    return true;
 }
+
+
+// ###### Add source addresses from file ####################################
+bool addSourceAddressesFromFile(std::map<boost::asio::ip::address, std::set<uint8_t>>& array,
+                                const std::filesystem::path&                           inputFileName,
+                                bool                                                   tryToResolve)
+{
+   std::ifstream is(inputFileName);
+   if(!is.is_open()) {
+      HPCT_LOG(error) << "Unable to open sources file " << inputFileName;
+      return false;
+   }
+
+   std::string line;
+   while (std::getline(is, line)) {
+      if(!addSourceAddress(array, line, tryToResolve)) {
+         return false;
+      }
+   }
+   return true;
+}
+
+
+// ###### Add destination addresses from file ###############################
+bool addDestinationAddressesFromFile(std::set<boost::asio::ip::address>& array,
+                                     const std::filesystem::path&        inputFileName,
+                                     bool                                tryToResolve)
+{
+   std::ifstream is(inputFileName);
+   if(!is.is_open()) {
+      HPCT_LOG(error) << "Unable to open destinations file " << inputFileName;
+      return false;
+   }
+
+   std::string line;
+   while (std::getline(is, line)) {
+      if(!addDestinationAddress(array, line, tryToResolve)) {
+         return false;
+      }
+   }
+   return true;
+}
